import { Inject, Injectable, UnauthorizedException } from '@nestjs/common';
import { PassportStrategy } from '@nestjs/passport';
import { ExtractJwt, Strategy } from 'passport-jwt';
import { AuthConfig, authConfig } from '../../auth.config';
import { RequestWithUser } from '../../constants/request-with-user';
import { TokenPayload } from '../../constants/token-payload.interface';
import { UsersAuthService } from '../../users/users-auth.service';

@Injectable()
export class JwtAccessTokenAuthStrategy extends PassportStrategy(Strategy, 'jwt-access-token') {
  constructor(@Inject(authConfig.KEY) authConfig: AuthConfig, private readonly userAuthService: UsersAuthService) {
    super({
      jwtFromRequest: ExtractJwt.fromAuthHeaderAsBearerToken(),
      secretOrKey: authConfig.accessToken.secret,
      passReqToCallback: true,
    });
  }

  async validate(request: RequestWithUser, payload: TokenPayload) {
    const account = await this.userAuthService.getUserById(payload.userId);
    if (!account) throw new UnauthorizedException('Access Token Guard');
    return account;
  }
}
