import { Injectable } from '@nestjs/common';
import { PassportStrategy } from '@nestjs/passport';
import { Strategy } from 'passport-local';
import { AuthService } from '../../auth.service';
import { RequestWithUser } from '../../constants/request-with-user';
import { AccountsEntity } from '../../../database/entities';

@Injectable()
export class LocalAuthStrategy extends PassportStrategy(Strategy, 'local') {
  constructor(private readonly authService: AuthService) {
    super({
      usernameField: 'username',
      passwordField: 'password',
      passReqToCallback: true,
    });
  }

  async validate(request: RequestWithUser, username: string, password: string): Promise<AccountsEntity> {
    const account = await this.authService.getAuthenticatedUser(username, password);
    return account;
  }
}
